<?php // Google Analytics - Validate Settings

if (!defined('ABSPATH')) exit;

function ga_google_analytics_pro_validate_settings($input) {
	
	// Configure
	
	if (isset($input['gapro_id'])) $input['gapro_id'] = wp_filter_nohtml_kses($input['gapro_id']);
	
	if (isset($input['gapro_id']) && preg_match("/^GTM-/i", $input['gapro_id'])) {
		
		$input['gapro_id'] = '';
		
		$message  = esc_html__('Error: your tracking code begins with', 'ga-google-analytics-pro') .' <code>GTM-</code> ';
		$message .= esc_html__('(for Google Tag Manager), which is not supported. Please try again with a supported tracking code.', 'ga-google-analytics-pro');
		
		add_settings_error('gapro_id', 'invalid-tracking-code', $message, 'error');
		
	}
	
	if (!isset($input['gapro_library'])) $input['gapro_library'] = null;
	if (!array_key_exists($input['gapro_library'], ga_google_analytics_pro_options_libraries())) $input['gapro_library'] = null;
	
	if (!isset($input['gapro_display_ads'])) $input['gapro_display_ads'] = null;
	$input['gapro_display_ads'] = ($input['gapro_display_ads'] == 1 ? 1 : 0);
	
	if (!isset($input['gapro_link_attr'])) $input['gapro_link_attr'] = null;
	$input['gapro_link_attr'] = ($input['gapro_link_attr'] == 1 ? 1 : 0);
	
	if (!isset($input['gapro_anonymize'])) $input['gapro_anonymize'] = null;
	$input['gapro_anonymize'] = ($input['gapro_anonymize'] == 1 ? 1 : 0);
	
	if (!isset($input['gapro_force_ssl'])) $input['gapro_force_ssl'] = null;
	$input['gapro_force_ssl'] = ($input['gapro_force_ssl'] == 1 ? 1 : 0);
	
	if (!isset($input['gapro_location'])) $input['gapro_location'] = null;
	if (!array_key_exists($input['gapro_location'], ga_google_analytics_pro_options_location())) $input['gapro_location'] = null;
	
	if (isset($input['tracker_object'])) $input['tracker_object'] = wp_filter_nohtml_kses(rtrim($input['tracker_object']));
	
	if (isset($input['custom_ga_code'])) $input['custom_ga_code'] = wp_filter_nohtml_kses(rtrim($input['custom_ga_code']));
	
	// Customize
	
	// 1
	if (isset($input['custom1_code'])) $input['custom1_code'] = stripslashes(rtrim($input['custom1_code']));
	
	if (isset($input['custom1_postids'])) $input['custom1_postids'] = wp_filter_nohtml_kses($input['custom1_postids']);
	
	if (!isset($input['custom1_admin'])) $input['custom1_admin'] = null;
	$input['custom1_admin'] = ($input['custom1_admin'] == 1 ? 1 : 0);
	
	if (!isset($input['custom1_frontend'])) $input['custom1_frontend'] = null;
	$input['custom1_frontend'] = ($input['custom1_frontend'] == 1 ? 1 : 0);
	
	if (!isset($input['custom1_position'])) $input['custom1_position'] = null;
	if (!array_key_exists($input['custom1_position'], ga_google_analytics_pro_options_position())) $input['custom1_position'] = null;
	
	// 2
	if (isset($input['custom2_code'])) $input['custom2_code'] = stripslashes(rtrim($input['custom2_code']));
	
	if (isset($input['custom2_postids'])) $input['custom2_postids'] = wp_filter_nohtml_kses($input['custom2_postids']);
	
	if (!isset($input['custom2_admin'])) $input['custom2_admin'] = null;
	$input['custom2_admin'] = ($input['custom2_admin'] == 1 ? 1 : 0);
	
	if (!isset($input['custom2_frontend'])) $input['custom2_frontend'] = null;
	$input['custom2_frontend'] = ($input['custom2_frontend'] == 1 ? 1 : 0);
	
	if (!isset($input['custom2_position'])) $input['custom2_position'] = null;
	if (!array_key_exists($input['custom2_position'], ga_google_analytics_pro_options_position())) $input['custom2_position'] = null;
	
	// 3
	if (isset($input['custom3_code'])) $input['custom3_code'] = stripslashes(rtrim($input['custom3_code']));
	
	if (isset($input['custom3_postids'])) $input['custom3_postids'] = wp_filter_nohtml_kses($input['custom3_postids']);
	
	if (!isset($input['custom3_admin'])) $input['custom3_admin'] = null;
	$input['custom3_admin'] = ($input['custom3_admin'] == 1 ? 1 : 0);
	
	if (!isset($input['custom3_frontend'])) $input['custom3_frontend'] = null;
	$input['custom3_frontend'] = ($input['custom3_frontend'] == 1 ? 1 : 0);
	
	if (!isset($input['custom3_position'])) $input['custom3_position'] = null;
	if (!array_key_exists($input['custom3_position'], ga_google_analytics_pro_options_position())) $input['custom3_position'] = null;
	
	// 4
	if (isset($input['custom4_code'])) $input['custom4_code'] = stripslashes(rtrim($input['custom4_code']));
	
	if (isset($input['custom4_postids'])) $input['custom4_postids'] = wp_filter_nohtml_kses($input['custom4_postids']);
	
	if (!isset($input['custom4_admin'])) $input['custom4_admin'] = null;
	$input['custom4_admin'] = ($input['custom4_admin'] == 1 ? 1 : 0);
	
	if (!isset($input['custom4_frontend'])) $input['custom4_frontend'] = null;
	$input['custom4_frontend'] = ($input['custom4_frontend'] == 1 ? 1 : 0);
	
	if (!isset($input['custom4_position'])) $input['custom4_position'] = null;
	if (!array_key_exists($input['custom4_position'], ga_google_analytics_pro_options_position())) $input['custom4_position'] = null;
	
	// 5
	if (isset($input['custom5_code'])) $input['custom5_code'] = stripslashes(rtrim($input['custom5_code']));
	
	if (isset($input['custom5_postids'])) $input['custom5_postids'] = wp_filter_nohtml_kses($input['custom5_postids']);
	
	if (!isset($input['custom5_admin'])) $input['custom5_admin'] = null;
	$input['custom5_admin'] = ($input['custom5_admin'] == 1 ? 1 : 0);
	
	if (!isset($input['custom5_frontend'])) $input['custom5_frontend'] = null;
	$input['custom5_frontend'] = ($input['custom5_frontend'] == 1 ? 1 : 0);
	
	if (!isset($input['custom5_position'])) $input['custom5_position'] = null;
	if (!array_key_exists($input['custom5_position'], ga_google_analytics_pro_options_position())) $input['custom5_position'] = null;
	
	// 6
	if (isset($input['custom6_code'])) $input['custom6_code'] = stripslashes(rtrim($input['custom6_code']));
	
	if (isset($input['custom6_postids'])) $input['custom6_postids'] = wp_filter_nohtml_kses($input['custom6_postids']);
	
	if (!isset($input['custom6_admin'])) $input['custom6_admin'] = null;
	$input['custom6_admin'] = ($input['custom6_admin'] == 1 ? 1 : 0);
	
	if (!isset($input['custom6_frontend'])) $input['custom6_frontend'] = null;
	$input['custom6_frontend'] = ($input['custom6_frontend'] == 1 ? 1 : 0);
	
	if (!isset($input['custom6_position'])) $input['custom6_position'] = null;
	if (!array_key_exists($input['custom6_position'], ga_google_analytics_pro_options_position())) $input['custom6_position'] = null;
	
	// Advanced
	
	if (!isset($input['login_page'])) $input['login_page'] = null;
	$input['login_page'] = ($input['login_page'] == 1 ? 1 : 0);
	
	if (!isset($input['admin_area'])) $input['admin_area'] = null;
	$input['admin_area'] = ($input['admin_area'] == 1 ? 1 : 0);
	
	if (!isset($input['disable_admin'])) $input['disable_admin'] = null;
	$input['disable_admin'] = ($input['disable_admin'] == 1 ? 1 : 0);
	
	if (!isset($input['disable_logged'])) $input['disable_logged'] = null;
	$input['disable_logged'] = ($input['disable_logged'] == 1 ? 1 : 0);
	
	if (isset($input['disable_post_ids'])) $input['disable_post_ids'] = wp_filter_nohtml_kses($input['disable_post_ids']);
	
	if (isset($input['disable_user_roles'])) $input['disable_user_roles'] = wp_filter_nohtml_kses($input['disable_user_roles']);
	
	if (isset($input['disable_post_types'])) $input['disable_post_types'] = wp_filter_nohtml_kses($input['disable_post_types']);
	
	if (!isset($input['disable_archives'])) $input['disable_archives'] = null;
	$input['disable_archives'] = ($input['disable_archives'] == 1 ? 1 : 0);
	
	if (!isset($input['disable_search'])) $input['disable_search'] = null;
	$input['disable_search'] = ($input['disable_search'] == 1 ? 1 : 0);
	
	// Opt Out
	
	if (!isset($input['optout_enable'])) $input['optout_enable'] = null;
	$input['optout_enable'] = ($input['optout_enable'] == 1 ? 1 : 0);
	
	if (!isset($input['optin_require'])) $input['optin_require'] = null;
	$input['optin_require'] = ($input['optin_require'] == 1 ? 1 : 0);
	
	if (!isset($input['disable_hide'])) $input['disable_hide'] = null;
	$input['disable_hide'] = ($input['disable_hide'] == 1 ? 1 : 0);
	
	if (!isset($input['disable_styles'])) $input['disable_styles'] = null;
	$input['disable_styles'] = ($input['disable_styles'] == 1 ? 1 : 0);
	
	if (isset($input['optout_text']))     $input['optout_text']     = wp_filter_nohtml_kses($input['optout_text']);
	if (isset($input['optin_text']))      $input['optin_text']      = wp_filter_nohtml_kses($input['optin_text']);
	if (isset($input['info_text']))       $input['info_text']       = wp_filter_nohtml_kses($input['info_text']);
	if (isset($input['success_optin']))   $input['success_optin']   = wp_filter_nohtml_kses($input['success_optin']);
	if (isset($input['success_optout']))  $input['success_optout']  = wp_filter_nohtml_kses($input['success_optout']);
	if (isset($input['css_color_text']))  $input['css_color_text']  = wp_filter_nohtml_kses($input['css_color_text']);
	if (isset($input['css_color_bg']))    $input['css_color_bg']    = wp_filter_nohtml_kses($input['css_color_bg']);
	if (isset($input['css_color_link']))  $input['css_color_link']  = wp_filter_nohtml_kses($input['css_color_link']);
	if (isset($input['css_color_hover'])) $input['css_color_hover'] = wp_filter_nohtml_kses($input['css_color_hover']);
	
	if (isset($input['optout_message'])) $input['optout_message'] = stripslashes(rtrim($input['optout_message']));
	
	if (isset($input['css_custom'])) $input['css_custom'] = wp_strip_all_tags($input['css_custom']);
	
	if (!isset($input['css_location'])) $input['css_location'] = null;
	if (!array_key_exists($input['css_location'], ga_google_analytics_pro_options_optout())) $input['css_location'] = null;
	
	return $input;
	
}
