<?php // Google Analytics - License & Activation

if (!defined('ABSPATH')) exit;

if (!class_exists('EDD_SL_Plugin_Updater')) {
	
	include(GAPRO_DIR .'updates/updater.php');
	
}

function ga_google_analytics_pro_plugin_updater() {
	
	$doing_cron = defined('DOING_CRON') && DOING_CRON;
	
	if (!current_user_can('manage_options') && !$doing_cron) return;
	
	$license_key = trim(get_option('gapro_license_key'));
	
	$edd_updater = new EDD_SL_Plugin_Updater(
		
		GAPRO_HOME, 
		GAPRO_FILE, 
		array(
			'license'   => $license_key,
			'item_name' => GAPRO_NAME,
			'author'    => GAPRO_AUTHOR,
			'version'   => GAPRO_VERSION,
			'url'       => GAPRO_HOME,
			'beta'		=> false
			
		)
		
	);
	
}
add_action('admin_init', 'ga_google_analytics_pro_plugin_updater', 0);

function ga_google_analytics_pro_license_register_option() {
	
	register_setting('gapro_license_settings', 'gapro_license_key', 'ga_google_analytics_pro_sanitize_option');
	
}
add_action('admin_init', 'ga_google_analytics_pro_license_register_option');

function ga_google_analytics_pro_sanitize_option($new) {
	
	$old = get_option('gapro_license_key');
	
	if ($old && $old != $new) delete_option('gapro_license_status');
	
	return $new;
	
}

function ga_google_analytics_pro_license_admin_notice() {
	
	$screen = get_current_screen();
	
	if ($screen->id === 'settings_page_ga-google-analytics-pro') {
		
		$status   = isset($_GET['license-status'])   ? urldecode($_GET['license-status'])   : '[n/a]';
		$response = isset($_GET['license-response']) ? urldecode($_GET['license-response']) : '[n/a]';
		
		if (isset($_GET['license-activate'])) {
			
			if ($_GET['license-activate'] === 'true') : ?>
				
				<div class="notice notice-success is-dismissible"><p><strong><?php esc_html_e('License activated.', 'ga-google-analytics-pro'); ?></strong></p></div>
				
			<?php else : ?>
				
				<div class="notice notice-warning is-dismissible"><p><strong><?php echo esc_html__('License not activated: ', 'ga-google-analytics-pro') . esc_html($response); ?></strong></p></div>
				
			<?php endif;
			
		} elseif (isset($_GET['license-deactivate'])) {
			
			if ($_GET['license-deactivate'] === 'true') : ?>
				
				<div class="notice notice-success is-dismissible"><p><strong><?php esc_html_e('License deactivated.', 'ga-google-analytics-pro'); ?></strong></p></div>
				
			<?php else : ?>
				
				<div class="notice notice-warning is-dismissible"><p><strong><?php echo esc_html__('License not deactivated: ', 'ga-google-analytics-pro') . esc_html($response); ?></strong></p></div>
				
			<?php endif;
			
		} elseif (isset($_GET['clear-license'])) {
			
			if ($_GET['clear-license'] === 'true') : ?>
				
				<div class="notice notice-success is-dismissible"><p><strong><?php esc_html_e('Done.', 'ga-google-analytics-pro'); ?></strong></p></div>
				
			<?php else : ?>
				
				<div class="notice notice-info is-dismissible"><p><strong><?php esc_html_e('No changes made.', 'ga-google-analytics-pro'); ?></strong></p></div>
				
			<?php endif;
			
		}
		
	}
	
}
add_action('admin_notices', 'ga_google_analytics_pro_license_admin_notice');

function ga_google_analytics_pro_display_license() {
	
	$license = get_option('gapro_license_key');
	$status  = get_option('gapro_license_status');
	
	settings_fields('gapro_license_settings');
	
	if (ga_google_analytics_pro_check_license()) :
		
		if (empty($license)) : // via code ?>
			
			<p class="gapro-success-code-enabled"><?php esc_html_e('Your GA Pro License is active.', 'ga-google-analytics-pro'); ?></p>
			
		<?php else : // active ?>
			
			<p>
				<code class="gapro-license-key"><?php esc_html_e(ga_google_analytics_pro_obfuscate($license)); ?></code>
				<label class="gapro-label gapro-success"><?php esc_html_e('Your GA Pro License is active.', 'ga-google-analytics-pro'); ?></label>
			</p>
			<p>
				<input type="submit" class="gapro-submit button button-primary" value="<?php esc_attr_e('Deactivate License', 'ga-google-analytics-pro'); ?>">
				<input type="hidden" name="gapro_license_key" value="<?php echo esc_attr($license); ?>">
				<?php wp_nonce_field('gapro_deactivate_license_nonce', 'gapro_license_nonce'); ?>
			</p>
			
		<?php endif; ?>
		
	<?php else : 
		
		if (empty($license)) : // empty ?>
			
			<p>
				<input type="password" class="gapro-license-input" id="gapro_license_key" name="gapro_license_key" value="<?php echo esc_attr($license); ?>">
				<?php echo ga_google_analytics_pro_reveal_text_link(); ?>
				<label class="gapro-label" for="gapro_license_key"><?php esc_html_e('Enter your License Key', 'ga-google-analytics-pro'); ?></label>
			</p>
			<p>
				<input type="submit" class="gapro-submit button button-primary" value="<?php esc_attr_e('Save License', 'ga-google-analytics-pro'); ?>">
				<?php wp_nonce_field('gapro_save_license_nonce', 'gapro_license_nonce'); ?>
			</p>
			
		<?php else : // entered ?>
			
			<p>
				<input type="password" class="gapro-license-input" id="gapro_license_key" name="gapro_license_key" value="<?php echo esc_attr($license); ?>"> 
				<?php echo ga_google_analytics_pro_clear_license_link(); ?>
				<label class="gapro-label gapro-warning" for="gapro_license_key"><?php esc_html_e('Your license is not active. Click the button to activate.', 'ga-google-analytics-pro'); ?></label>
			</p>
			<p>
				<input type="submit" class="gapro-submit button button-primary" value="<?php esc_attr_e('Activate License', 'ga-google-analytics-pro'); ?>">
				<?php wp_nonce_field('gapro_activate_license_nonce', 'gapro_license_nonce'); ?>
			</p>
			
		<?php endif; ?>
		
	<?php endif;
	
}

function ga_google_analytics_pro_obfuscate($string) {
	
	$result = '';
	
	$i = 0;
	
	while ($i < intval(strlen($string))) {
			
		$result .= '*';
		
		$i++;
		
	} 
	
	return $result;
	
}

function ga_google_analytics_pro_activate_license() {
	
	if (isset($_POST['gapro_license_nonce']) && wp_verify_nonce($_POST['gapro_license_nonce'], 'gapro_activate_license_nonce')) {
		
		if (!current_user_can('manage_options')) exit;
		
		$key = trim(get_option('gapro_license_key'));
		
		$api_params = array('edd_action' => 'activate_license', 'license' => $key, 'item_name' => urlencode(GAPRO_NAME), 'url' => home_url());
		
		$response = wp_remote_post(GAPRO_HOME, array('timeout' => 15, 'sslverify' => false, 'body' => $api_params));
		
		$license = 'error';
		
		$updated = false;
		
		if (is_wp_error($response) || 200 !== wp_remote_retrieve_response_code($response)) {
			
			if (is_wp_error($response)) $message = $response->get_error_message();
			else $message = __('An error occurred, please try again.', 'ga-google-analytics-pro');
			
		} else {
			
			$license_data = json_decode(wp_remote_retrieve_body($response));
			
			if ($license_data->success === true) {
				
				$license = $license_data->license;
				
				$updated = update_option('gapro_license_status', $license);
				
				$message = __('License activated.', 'ga-google-analytics-pro');
				
			} else {
				
				switch($license_data->error) {
					
					case 'expired' :
						
						$message = sprintf(__('Your license key expired on %s.', 'ga-google-analytics-pro'), 
								   date_i18n(get_option('date_format'), 
								   strtotime($license_data->expires, 
								   current_time('timestamp'))));
						break;
						
					case 'disabled' :
						
						$message = __('Your license key has been disabled.', 'banhammer-pro');
						break;
						
					case 'revoked' :
						
						$message = __('Your license key has been disabled.', 'ga-google-analytics-pro');
						break;
						
					case 'missing' :
						
						$message = __('Invalid license.', 'ga-google-analytics-pro');
						break;
						
					case 'invalid' :
						
						$message = __('Invalid license.', 'ga-google-analytics-pro');
						break;
						
					case 'site_inactive' :
						
						$message = __('Your license is not active for this URL.', 'ga-google-analytics-pro');
						break;
						
					case 'item_name_mismatch' :
						
						$message = sprintf(__('This appears to be an invalid license key for %s.', 'ga-google-analytics-pro'), GAPRO_NAME);
						break;
						
					case 'no_activations_left':
						
						$message = __('Your license key has reached its activation limit.', 'ga-google-analytics-pro');
						break;
						
					default :
						
						$message = __('An error occurred, please try again.', 'ga-google-analytics-pro');
						break;
					
				}
				
			}
			
		}
		
		$result = ($updated && $license === 'valid') ? 'true' : 'false';
		
		$params = array('license-activate' => $result, 'license-response' => urlencode($message), 'license-status' => $license);
		
		$path = admin_url('options-general.php?page=ga-google-analytics-pro&tab=tab6');
		
		$location = add_query_arg($params, $path);
		
		wp_redirect($location);
		
		exit;
		
	}
	
}
add_action('admin_init', 'ga_google_analytics_pro_activate_license');

function ga_google_analytics_pro_deactivate_license() {
	
	if (isset($_POST['gapro_license_nonce']) && wp_verify_nonce($_POST['gapro_license_nonce'], 'gapro_deactivate_license_nonce')) {
		
		if (!current_user_can('manage_options')) exit;
		
		$key = trim(get_option('gapro_license_key'));
		
		$api_params = array('edd_action' => 'deactivate_license', 'license' => $key, 'item_name' => urlencode(GAPRO_NAME), 'url' => home_url());
		
		$response = wp_remote_post(GAPRO_HOME, array('timeout' => 15, 'sslverify' => false, 'body' => $api_params));
		
		$license = 'error';
		
		$updated = false;
		
		if (is_wp_error($response) || 200 !== wp_remote_retrieve_response_code($response)) {
			
			if (is_wp_error($response)) $message = $response->get_error_message();
			else $message = __('An error occurred, please try again.', 'ga-google-analytics-pro');
			
		} else {
			
			$license_data = json_decode(wp_remote_retrieve_body($response));
			
			$license = $license_data->license;
			
			$updated = ($license === 'deactivated') ? delete_option('gapro_license_status') : false;
			
			$message = __('License deactivated.', 'ga-google-analytics-pro');
			
		}
		
		$result = ($updated && $license === 'deactivated') ? 'true' : 'false';
		
		$params = array('license-deactivate' => $result, 'license-response' => urlencode($message), 'license-status' => $license);
		
		$path = admin_url('options-general.php?page=ga-google-analytics-pro&tab=tab6');
		
		$location = add_query_arg($params, $path);
		
		wp_redirect($location);
		
		exit;
		
	}
	
}
add_action('admin_init', 'ga_google_analytics_pro_deactivate_license');

function ga_google_analytics_pro_check_license() {
		
	$status = get_option('gapro_license_status');
	
	if ($status === 'valid' || GAPRO_CODE) return true;
	
	return false;
	
}

function ga_google_analytics_pro_invite_license($tab) {
	
	$url = ($tab === 'tab6') ? GAPRO_HOME : admin_url('options-general.php?page=ga-google-analytics-pro&tab=tab6');
	
	$target = ($tab === 'tab6') ? 'target="_blank" rel="noopener noreferrer" ' : '';
	
	$output = '<h2>'. esc_html__('License Key', 'ga-google-analytics-pro') .'</h2>';
	$output .= '<p><a '. $target .'href="'. esc_url($url) .'">'. esc_html__('Activate your license', 'ga-google-analytics-pro') .'</a> ';
	$output .= esc_html__('to enable GA Pro and free automatic updates. Visit the Help tab for details.', 'ga-google-analytics-pro') .'</p>';
	
	return $output;
	
}

function ga_google_analytics_pro_clear_license_link() {
	
	$nonce = wp_create_nonce('gapro_clear_license');
	$href  = esc_url(add_query_arg(array('gapro-clear-license-verify' => $nonce), admin_url('options-general.php?page=ga-google-analytics-pro&tab=tab6')));
	$title = esc_html__('Clear license field', 'ga-google-analytics-pro');
	$label = esc_html__('&times;', 'ga-google-analytics-pro');
	
	return '<a class="gapro-license-clear" href="'. $href .'" title="'. $title .'">'. $label .'</a>';
	
}
add_action('admin_init', 'ga_google_analytics_pro_clear_license_link');

function ga_google_analytics_pro_clear_license() {
	
	if (isset($_GET['gapro-clear-license-verify']) && wp_verify_nonce($_GET['gapro-clear-license-verify'], 'gapro_clear_license')) {
		
		if (!current_user_can('manage_options')) exit;
		
		$delete_key    = delete_option('gapro_license_key');
		$delete_status = delete_option('gapro_license_status');
		
		$result = ($delete_key) ? 'true' : 'false';
		
		$location = admin_url('options-general.php?page=ga-google-analytics-pro&tab=tab6&clear-license='. $result);
		
		wp_redirect($location);
		
		exit;
		
	}
	
}
add_action('admin_init', 'ga_google_analytics_pro_clear_license');

function ga_google_analytics_pro_reveal_text_link() {
	
	$title = esc_html__('Show License', 'ga-google-analytics-pro');
	
	return '<a class="gapro-reveal-text" href="#gapro-reveal-text" data-type="password" title="'. $title .'"><span class="fa fa-eye"></span></a>';
	
}
