<?php

/********************
* ADVANCED SETTINGS *
********************/

/**
 * Register settings
 */
function xmlsf_news_register_settings() {
	// register settings
	register_setting (
		'xmlsf_news_advanced',
		'xmlsf_news_advanced',
		'xmlsf_news_sanitize_advanced_settings'
	);
	register_setting (
		'xmlsf_news_license',
		'xmlsf_news_license',
		'xmlsf_news_sanitize_license'
	);
	register_setting (
		'xmlsf_news_log',
		'xmlsf_news_log_clear',
		'xmlsf_news_sanitize_log_clear'
	);

	// replace advanced tab options
	remove_action ( 'xmlsf_news_settings_before', 'xmlsf_news_section_advanced_intro' );
	add_action ( 'xmlsf_news_settings_before', 'xmlsf_news_advanced_section_intro' );
	//remove_action( 'xmlsf_news_add_settings', array( 'XMLSF_Admin_Sitemap_News', 'advanced_settings_fields' ) );
	add_action ( 'xmlsf_news_add_settings', 'xmlsf_news_advanced_add_settings' );

	// add a ping log tab
	add_action ( 'xmlsf_news_nav_tabs', 'xmlsf_news_advanced_add_tab_log' );

	// add a license tab
	add_action ( 'xmlsf_news_nav_tabs', 'xmlsf_news_advanced_add_tab_license' );
}

/**
 * Add settings sections and fields
 */
function xmlsf_news_advanced_add_settings( $active_tab = '' ) {
	if ( 'advanced' == $active_tab ) {
		// Hierarchical post types
		add_settings_field (
			'xmlsf_news_hierarchical',
			__( 'Hierarchical post types', 'xml-sitemap-feed' ),
			'xmlsf_news_hierarchical_field',
			'xmlsf_news_advanced',
			'news_sitemap_advanced_section'
		);

		// Keywords
		add_settings_field (
			'xmlsf_news_keywords',
			__('Keywords', 'xml-sitemap-feed' ),
			'xmlsf_news_keywords_field',
			'xmlsf_news_advanced',
			'news_sitemap_advanced_section'
		);

		// Stock tickers
		add_settings_field (
			'xmlsf_news_stock_tickers',
			__('Stock tickers', 'xml-sitemap-feed' ),
			'xmlsf_news_stock_tickers_field',
			'xmlsf_news_advanced',
			'news_sitemap_advanced_section'
		);

		// Ping log
		add_settings_field (
			'xmlsf_news_ping_log',
			__('Ping log', 'xml-sitemap-feed' ),
			'xmlsf_news_ping_log_field',
			'xmlsf_news_advanced',
			'news_sitemap_advanced_section'
		);
	}

	if ( 'log' == $active_tab ) {
		// LOG SECTION
		add_settings_section (
			'news_sitemap_log_section',
			'',
			'',
			'xmlsf_news_log'
		);

		// Log settings
		add_settings_field (
			'xmlsf_news_log_view',
			__('View log', 'xml-sitemap-feed' ),
			function() { $log = get_option('xmlsf_news_log'); include XMLSF_NEWS_ADV_DIR . '/views/field-news-log.php'; },
			'xmlsf_news_log',
			'news_sitemap_log_section'
		);

		add_settings_field (
			'xmlsf_news_log_clear',
			__('Clear log', 'xml-sitemap-feed' ),
			function() { include XMLSF_NEWS_ADV_DIR . '/views/field-news-log-clear.php'; },
			'xmlsf_news_log',
			'news_sitemap_log_section'
		);

	}

	if ( 'license' == $active_tab ) {
		// LICENSE SECTION
		add_settings_section (
			'news_sitemap_license_section',
			'',
			'',
			'xmlsf_news_license'
		);

		// License key.
		add_settings_field (
			'xmlsf_news_license_key',
			'<label for="xmlsf_news_license_key">'.__('License key', 'xml-sitemap-feed' ).'</label>',
			'xmlsf_news_license_key_field',
			'xmlsf_news_license',
			'news_sitemap_license_section'
		);

		// Beta version.
		add_settings_field (
			'xmlsf_news_license_beta',
			'<label for="xmlsf_news_license_beta">'.__('Beta version', 'xml-sitemap-feed' ).'</label>',
			'xmlsf_news_license_beta_field',
			'xmlsf_news_license',
			'news_sitemap_license_section'
		);	

		// License action.
		add_settings_field (
			'xmlsf_news_license_action',
			__('License action', 'xml-sitemap-feed' ),
			'xmlsf_news_license_action_field',
			'xmlsf_news_license',
			'news_sitemap_license_section'
		);

	}
}

/**
 * Hook section intros
 */
function xmlsf_news_advanced_section_intro( $active_tab = '' ) {
	if ( 'advanced' == $active_tab )
		include XMLSF_NEWS_ADV_DIR . '/views/section-advanced-intro.php';
	if ( 'license' == $active_tab )
		include XMLSF_NEWS_ADV_DIR . '/views/section-license-intro.php';
}

/**
 * Settings fields
 */

function xmlsf_news_hierarchical_field() {
	$options = get_option('xmlsf_news_advanced');

	$allow_hierarchical = !empty($options['allow_hierarchical']);

 	// The actual fields for data entry.
 	include XMLSF_NEWS_ADV_DIR . '/views/field-news-hierarchical.php';
}

function xmlsf_news_keywords_field() {
	$options = get_option('xmlsf_news_advanced');
	$keywords_from = !empty( $options['keywords_from'] ) ? $options['keywords_from'] : '';

	$options = get_option('xmlsf_news_tags');
	$news_post_type = isset( $options['post_type'] ) && !empty( $options['post_type'] ) ? $options['post_type'] : 'post';

	$taxonomies = xmlsf_news_available_taxonomies( $news_post_type );

	// The actual fields for data entry.
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-keywords.php';
}

function xmlsf_news_stock_tickers_field() {
	$options = get_option('xmlsf_news_advanced');

	$stock_tickers = !empty($options['stock_tickers']);

	// The actual fields for data entry.
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-stocktickers.php';
}

function xmlsf_news_ping_log_field() {
	$options = get_option('xmlsf_news_advanced');

	$ping_log = !empty($options['ping_log']);
	$ping_log_max = !empty($options['ping_log_max']) && is_numeric($options['ping_log_max']) ? $options['ping_log_max'] : '1000';

	// The actual fields for data entry.
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-ping-log.php';
}

function xmlsf_news_license_key_field() {
	// Get license data.
	$data = (array) get_option( 'xmlsf_news_license', array() );

	$key = isset( $data['key'] ) ? $data['key'] : '';
	$status = isset( $data['status'] ) ? $data['status'] : '';
	$expires = isset( $data['expires'] ) ? $data['expires'] : '';
	//$lifetime = ! empty($data['lifetime']);
	$error = isset( $data['error'] ) ? $data['error'] : '';
	$account_url = ! empty( $data['payment_id'] ) ? trailingslashit( XMLSF_NEWS_ADV_STORE_URL ) . 'account/?action=manage_licenses&payment_id=' . $data['payment_id'] : trailingslashit( XMLSF_NEWS_ADV_STORE_URL ) . 'account/';

	// The actual fields for data entry.
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-license-key.php';
}

function xmlsf_news_license_beta_field() {
	// Get license data.
	$data = (array) get_option( 'xmlsf_news_license', array() );

	$beta = isset( $data['beta'] ) ? $data['beta'] : '';
	$account_url = trailingslashit( XMLSF_NEWS_ADV_STORE_URL ) . 'account/#tab-downloads';

	// The actual fields for data entry.
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-license-beta.php';
}

function xmlsf_news_license_action_field() {
	// Get license data.
	$data = (array) get_option( 'xmlsf_news_license', array() );

	$status = isset( $data['status'] ) ? $data['status'] : '';
	$account_url = ! empty( $data['payment_id'] ) ? trailingslashit( XMLSF_NEWS_ADV_STORE_URL ) . 'account/?action=manage_licenses&payment_id=' . $data['payment_id'] : trailingslashit( XMLSF_NEWS_ADV_STORE_URL ) . 'account/#tab-purchasehistory';

	// The actual fields for data entry.
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-license-action.php';
}

/**
 * Tabs
 */

function xmlsf_news_advanced_add_tab_log( $active_tab = '' ) {
	$options = get_option('xmlsf_news_advanced');
	if ( !empty($options['ping_log']) )
		include XMLSF_NEWS_ADV_DIR . '/views/nav-tab-log.php';
}

function xmlsf_news_advanced_add_tab_license( $active_tab = '' ) {
		include XMLSF_NEWS_ADV_DIR . '/views/nav-tab-license.php';
}

/**
 * Check license validity and set nag
 */

function xmlsf_news_license_admin_nag() {
	// retrieve our license key from the DB
	$option = (array) get_option( 'xmlsf_news_license', array() );
	$key = isset( $option['key'] ) ? trim( $option['key'] ) : '';
	$status = isset($option['status']) ? $option['status'] : '';

	if ( empty($key) ) {
		add_action( 'admin_notices',
			function() {
				echo '<div class="notice notice-error fade is-dismissible"><p>';
				printf( /* Translators: Plugin name */ __('You have not yet entered your license key for %s.','xml-sitemap-feed'), __('Google News Advanced','xml-sitemap-feed') );
				echo ' ';
				printf( /* Translators: Plugin name, correct this issue (linked) */
					__('To receive plugin updates, please %s.','xml-sitemap-feed'),
					'<a href="' . admin_url('options-general.php') . '?page=xmlsf_news&tab=license">' . __('correct this issue','xml-sitemap-feed') . '</a>'
				);
				echo '</p></div>';
			}
		);
	} elseif ( 'expired' == $status || 'invalid' == $status ) {
		add_action( 'admin_notices',
			function() {
				echo '<div class="notice notice-error fade is-dismissible"><p>';
				printf( /* Translators: Plugin name */ __('You have an invalid or expired license key for %s.','xml-sitemap-feed'), __('Google News Advanced','xml-sitemap-feed') );
				echo ' ';
				printf( /* Translators: Plugin name, correct this issue (linked) */
					__('To receive plugin updates, please %s.','xml-sitemap-feed'),
					'<a href="' . admin_url('options-general.php') . '?page=xmlsf_news&tab=license">' . __('correct this issue','xml-sitemap-feed') . '</a>'
				);
				echo '</p></div>';
			}
		);
	} elseif ( 'inactive' == $status ) {
		add_action( 'admin_notices',
			function() {
				echo '<div class="notice notice-warning fade is-dismissible"><p>';
				printf( /* Translators: Plugin name */ __('Your license key for %s is not activated for this site.','xml-sitemap-feed'), __('Google News Advanced','xml-sitemap-feed') );
				echo ' ';
				printf( /* Translators: Plugin name, correct this issue (linked) */
					__('To receive plugin updates, please %s.','xml-sitemap-feed'),
					'<a href="' . admin_url('options-general.php') . '?page=xmlsf_news&tab=license">' . __('correct this issue','xml-sitemap-feed') . '</a>'
				);
				echo '</p></div>';
			}
		);
	}
}

/**
 * License error messages 
 */

function xmlsf_news_license_admin_error_msg( $response, $license ) {
	if ( is_wp_error( $response ) ) {
		add_settings_error( 'xmlsf_news_license', 'xmlsf_news_license_notice', $response->get_error_message(), 'notice-error' );
		return;
	}
	
	if ( is_numeric( $response ) ) {
		switch( $response ) {
			case 429:
				add_settings_error( 'xmlsf_news_license', 'xmlsf_news_license_notice', __( 'Too many requests. Please try again in a minute.', 'xml-sitemap-feed' ), 'notice-error' );
				break;

			default:
				add_settings_error( 'xmlsf_news_license', 'xmlsf_news_license_notice', sprintf( /* Translators: http repsonse code, Support (linked) */ __( 'Unexpected response code %1$s. Please try again or get %2$s.', 'xml-sitemap-feed' ), '<code>' . $response . '</code>', '<a target="_blank" href="https://premium.status301.com/support-ticket/">' . __('Support','xml-sitemap-feed') . '</a>' ), 'notice-error' );

		}
		return;
	}
	
	if ( is_object($license) ) {
		$message = xmlsf_news_license_error_msg( $license->error, $license->expires );
		if ( $message ) {
			add_settings_error( 'xmlsf_news_license', 'xmlsf_news_license_notice', $message, 'notice-error' );
		} else {
			add_settings_error( 'xmlsf_news_license', 'xmlsf_news_license_notice', sprintf( /* Translators: license error code, Support (linked) */ __( 'Unexpected license error code %1$s. Please try again or get %2$s.', 'xml-sitemap-feed' ), '<code>' . $license->error . '</code>', '<a target="_blank" href="https://premium.status301.com/support-ticket/">' . __('Support','xml-sitemap-feed') . '</a>' ), 'notice-error' );
		}
		return;
	}
	
	add_settings_error( 'xmlsf_news_license', 'xmlsf_news_license_notice', __( 'An unkown error occurred. Please try again.', 'xml-sitemap-feed' ), 'notice-error' );
}

/* TODO Prime meta caches button
if ( isset( $_POST['xmlsf-prime-post-meta'] ) ) {
	if ( xmlsf_verify_nonce('help') ) {
		// prime metadata
		xmlsf_sitemap()->prime_post_meta();
		// TODO split this into post types, and maybe into months?

		// TODO consider same approach for term meta

		add_settings_error( 'prime_meta_notice', 'prime_meta_notice', __('Sitemap post meta cache has been primed.','xml-sitemap-feed'), 'updated' );
	}
}
// ADMIN BUTTON
<input type="submit" name="xmlsf-prime-post-meta" class="button button-small" value="<?php _e( 'Prime post meta caches', 'xml-sitemap-feed' ); ?>" />

/**
 * Prime post images and comment meta data
 *
 * @since 5.2
 *
 * @param string $post_type Post type slug
 * @param intval|null $m Year and month: YYYYMM
 *
public function prime_post_meta( $post_type = 'any', $m = null )
{
	// get our posts
	if ( !is_admin() && is_sitemap() ) {
		// we're a sitemap, so let's work with main query here
		global $wp_query;
		$posts = is_object($wp_query) ? $wp_query->$posts : array();
	} else {
		$args = array(
			'post_type' => $post_type,
			'numberposts' => -1,
			'lang' => '',
			'has_password' => false,
			'update_cache' => false
		);
		if ( is_numeric($m) ) $args['m'] = intval($m);
		$posts = get_posts( $args );

		// try to raise memory limit, context added for filters
		//wp_raise_memory_limit( 'sitemap-posttype-'.$post_type ); // already on admin...
	}

	foreach ( $posts as $post ) {
		if ( ! array_key_exists($post->post_type, $this->post_types) ) continue;

		// Update images meta
		//delete_post_meta( $post->ID, '_xmlsf_image_featured' );
		//delete_post_meta( $post->ID, '_xmlsf_image_attached' );

		if ( !empty($this->post_types[$post->post_type]['tags']['image']) ) {
			$which = $this->post_types[$post->post_type]['tags']['image'];

			$stored = (array) get_post_meta( $post->ID, '_xmlsf_image_'.$which );

			// populate images and add as meta data
			foreach ( xmlsf_images_data( $post, $which ) as $data ) {
				if ( ! in_array( $data, $stored ) )
					add_post_meta( $post->ID, '_xmlsf_image_'.$which, $data );
			}
		}

		// Update last comment date meta
		if ( ! empty($this->post_types[$post->post_type]['update_lastmod_on_comments']) ) {
			// get latest post comment
			$comments = get_comments( array(
				'status' => 'approve',
				'number' => 1,
				'post_id' => $post->ID,
			) );

			if ( isset( $comments[0]->comment_date ) )
				update_post_meta( $post->ID, '_xmlsf_comment_date_gmt', $comments[0]->comment_date_gmt );
			//else
				//delete_post_meta( $post->ID, '_xmlsf_comment_date_gmt' );
		}
	}
}

*/
