<?php
/*
Plugin Name: XML Sitemap & Google News - Google News Advanced
Plugin URI: https://premium.status301.com/downloads/google-news-advanced/
Description: Advanced options for your Google News sitemap
Text Domain: xmlsf-news-advanced
Version: 1.3.1
Author: RavanH
Author URI: http://status301.net/
*/

defined( 'WPINC' ) || die;

define( 'XMLSF_NEWS_ADV_VERSION', '1.3.1' );
define( 'XMLSF_NEWS_ADV_DIR', dirname( __FILE__ ) );

define( 'XMLSF_NEWS_ADV_STORE_URL', 'https://premium.status301.com' );
define( 'XMLSF_NEWS_ADV_ITEM_ID', 13480 );

/* --------------------------
 *        INITIALIZE
 * -------------------------- */

function xmlsf_advanced_news() {

	// Upgrade/install, maybe...
	$db_version = get_option( 'xmlsf_advanced_news_version', 0 );
	if ( ! version_compare( XMLSF_NEWS_ADV_VERSION, $db_version, '=' ) ) {
		require_once XMLSF_NEWS_ADV_DIR . '/upgrade.php';
		new XMLSitemapFeed_News_Advanced_Upgrade( $db_version );
	}

	$sitemaps = get_option( 'xmlsf_sitemaps' );

	if ( ! empty( $sitemaps['sitemap-news'] ) ) {

		include XMLSF_NEWS_ADV_DIR . '/controllers/functions.php';
		xmlsf_news_taxonomies();
		add_action( 'xmlsf_ping', 'xmlsf_news_log_ping', 10, 4 );

		include XMLSF_NEWS_ADV_DIR . '/models/functions.php';
		add_filter( 'request', 'xmlsf_advanced_news_filter_request', 1 );
		add_filter( 'xmlsf_news_post_types', 'xmlsf_advanced_news_allow_hierarchical', 11 );

		// TODO make proper rss template (with full post_content!)
	}

}

add_action( 'init', 'xmlsf_advanced_news', 9 );

/* --------------------------
 *     INITIALIZE ADMIN
 * -------------------------- */

function xmlsf_advanced_news_admin() {

	// Add support link to the plugin meta description.
	add_filter( 'plugin_row_meta', function( $links, $file ) {
		if ( $file == plugin_basename( __FILE__ ) ) {
			$links[] = '<a target="_blank" href="https://premium.status301.com/support/forum/xml-sitemap-google-news/google-news/">' . __('Support','xml-sitemap-feed') . '</a>';
		}
		return $links;
	}, 10, 2);

	// Check if main plugin is activated.
	if ( ! function_exists('xmlsf_init') ) {
		// Add admin message.
		if ( ! file_exists( trailingslashit( WP_PLUGIN_DIR ) . 'xml-sitemap-feed/xml-sitemap.php' ) ) {
			add_action( 'admin_notices', function() {
				add_thickbox();
				include XMLSF_NEWS_ADV_DIR . '/views/admin-notice-install-plugin.php';
			} );
		} else {
			add_action( 'admin_notices', function() {
				include XMLSF_NEWS_ADV_DIR . '/views/admin-notice-activate-plugin.php';
			} );
		}
		// And abort.
		return;
	}

	$sitemaps = get_option( 'xmlsf_sitemaps' );

	// Check if News Sitemap activated.
	if ( empty( $sitemaps['sitemap-news'] ) ) {
		// Add admin message.
		add_action( 'admin_notices', function() {
			include XMLSF_NEWS_ADV_DIR . '/views/admin-notice-activate-sitemap.php';
		} );
		// And abort.
		return;
	}

	// Include admin files.
	include XMLSF_NEWS_ADV_DIR . '/controllers/functions.admin.php';
	include XMLSF_NEWS_ADV_DIR . '/models/functions.admin.php';

	// Initiate
	xmlsf_news_license_admin_nag();
	xmlsf_news_register_settings();

	// Filter.
	add_filter( 'xmlsf_news_post_type_field_type', 'xmlsf_news_post_type_field_type' );

}

add_action( 'admin_init', 'xmlsf_advanced_news_admin', 0 );

/*********************
*   Plugin Updater   *
*********************/

/**
 * Updater
 *
 * Check plugin updates. Allows auto-updates, available in updater class v.1.8.0
 * Calls xmlsf_news_check_license() to check license prior to update check.
 *
 * @since 0.4
 *
 * @uses class EDD_SL_Plugin_Updater, xmlsf_news_check_license()
 *
 * @return void
 */

function xmlsf_advanced_news_plugin_updater() {

	// To support auto-updates, this needs to run during the wp_version_check cron job for privileged users.
	$doing_cron = defined( 'DOING_CRON' ) && DOING_CRON;
	if ( ! current_user_can( 'manage_options' ) && ! $doing_cron ) {
		return;
	}

	// Retrieve license data.
	$data = (array) get_option( 'xmlsf_news_license', array() );
		
	// Retrieve license key.
	$key = isset( $data['key'] ) ? trim( $data['key'] ) : '';

	if ( !class_exists( 'EDD_SL_Plugin_Updater' ) ) {
		include XMLSF_NEWS_ADV_DIR . '/vendor/EDD_SL_Plugin_Updater.php';
	}

	// Setup the updater.
	new EDD_SL_Plugin_Updater(
		XMLSF_NEWS_ADV_STORE_URL,
		__FILE__,
		array(
			'version' => XMLSF_NEWS_ADV_VERSION, // current version number
			'license' => $key,                   // license key (used get_option above to retrieve from DB)
			'item_id' => XMLSF_NEWS_ADV_ITEM_ID, // ID of the product
			'author'  => 'RavanH',               // author of this plugin
			'beta'    => ! empty( $data['beta'] )
		)
	);
}

add_action( 'init', 'xmlsf_advanced_news_plugin_updater' );

/****************************
*    De/activation hooks    *
****************************/

register_activation_hook( __FILE__, function() {
	activate_plugin( 'xml-sitemap-feed/xml-sitemap.php' );
} );